@@ -2,8 +2,6 @@
 
 __author__ = """Sahand Seifi"""
 __email__ = 'sahand.seifi@gmail.com'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 
-def hello():
-    return "Hello World"
